=== modified file 'NEWS'
--- NEWS	2008-11-29 02:01:21 +0000
+++ NEWS	2008-12-01 23:20:22 +0000
@@ -20,6 +20,14 @@
       PyErr_NoMemory() before returning NULL in PatienceSequenceMatcher_new.
       (Andrew Bennetts, #303206)
 
+    * Give proper error message for diff with non-existent dotted revno.
+      (Marius Kruger, #301969)
+
+    * ``Transport.readv()`` defaults to not reading more than 100MB in a
+      single array. Further ``RemoteTransport.readv`` sets this to 5MB to
+      work better with how it splits its requests.
+      (John Arbash Meinel, #303538)
+
   DOCUMENTATION:
 
   API CHANGES:

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2008-11-27 06:29:56 +0000
+++ bzrlib/branch.py	2008-12-01 23:50:52 +0000
@@ -1269,6 +1269,7 @@
     def __init__(self):
         super(BranchFormatMetadir, self).__init__()
         self._matchingbzrdir = bzrdir.BzrDirMetaFormat1()
+        self._matchingbzrdir.set_branch_format(self)
 
     def supports_tags(self):
         return True
@@ -1424,6 +1425,7 @@
     def __init__(self):
         super(BranchReferenceFormat, self).__init__()
         self._matchingbzrdir = bzrdir.BzrDirMetaFormat1()
+        self._matchingbzrdir.set_branch_format(self)
 
     def _make_reference_clone_function(format, a_branch):
         """Create a clone() routine for a branch dynamically."""

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2008-11-07 23:17:05 +0000
+++ bzrlib/bzrdir.py	2008-12-01 19:07:21 +0000
@@ -2650,6 +2650,11 @@
             return False
         return self.get_format_description() == other.get_format_description()
 
+    @property
+    def repository_format(self):
+        # Using a property to avoid early loading of remote
+        return remote.RemoteRepositoryFormat()
+
 
 BzrDirFormat.register_control_server_format(RemoteBzrDirFormat)
 

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2008-11-18 21:43:36 +0000
+++ bzrlib/remote.py	2008-12-01 23:50:52 +0000
@@ -1279,6 +1279,11 @@
 
 class RemoteBranchFormat(branch.BranchFormat):
 
+    def __init__(self):
+        super(RemoteBranchFormat, self).__init__()
+        self._matchingbzrdir = RemoteBzrDirFormat()
+        self._matchingbzrdir.set_branch_format(self)
+
     def __eq__(self, other):
         return (isinstance(other, RemoteBranchFormat) and 
             self.__dict__ == other.__dict__)

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2008-11-27 09:00:45 +0000
+++ bzrlib/repofmt/pack_repo.py	2008-12-01 19:07:21 +0000
@@ -2313,8 +2313,10 @@
         return xml7.serializer_v7
 
     def _get_matching_bzrdir(self):
-        return bzrdir.format_registry.make_bzrdir(
+        matching = bzrdir.format_registry.make_bzrdir(
             '1.6.1-rich-root')
+        matching.repository_format = self
+        return matching
 
     def _ignore_setting_bzrdir(self, format):
         pass

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2008-11-28 02:33:04 +0000
+++ bzrlib/repository.py	2008-12-01 19:07:21 +0000
@@ -2258,7 +2258,12 @@
     rich_root_data = False
     supports_tree_reference = False
     supports_external_lookups = False
-    _matchingbzrdir = bzrdir.BzrDirMetaFormat1()
+
+    @property
+    def _matchingbzrdir(self):
+        matching = bzrdir.BzrDirMetaFormat1()
+        matching.repository_format = self
+        return matching
 
     def __init__(self):
         super(MetaDirRepositoryFormat, self).__init__()

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2008-10-01 05:40:45 +0000
+++ bzrlib/revisionspec.py	2008-12-01 17:37:44 +0000
@@ -361,7 +361,7 @@
             finally:
                 branch.unlock()
             if len(revisions) != 1:
-                return branch, None, None
+                raise errors.InvalidRevisionSpec(self.user_spec, branch)
             else:
                 # there is no traditional 'revno' for dotted-decimal revnos.
                 # so for  API compatability we return None.

=== modified file 'bzrlib/tests/blackbox/test_diff.py'
--- bzrlib/tests/blackbox/test_diff.py	2008-01-04 00:26:05 +0000
+++ bzrlib/tests/blackbox/test_diff.py	2008-11-30 19:51:17 +0000
@@ -126,12 +126,27 @@
         # Get an error from a file that does not exist at all
         # (Malone #3619)
         self.make_example_branch()
-        out, err = self.run_bzr('diff does-not-exist', retcode=3)
-        self.assertContainsRe(err, 'not versioned.*does-not-exist')
+        out, err = self.run_bzr('diff does-not-exist', retcode=3,
+            error_regexes=('not versioned.*does-not-exist',))
 
     def test_diff_illegal_revision_specifiers(self):
-        out, err = self.run_bzr('diff -r 1..23..123', retcode=3)
-        self.assertContainsRe(err, 'one or two revision specifiers')
+        out, err = self.run_bzr('diff -r 1..23..123', retcode=3,
+            error_regexes=('one or two revision specifiers',))
+
+    def test_diff_nonexistent_revision(self):
+        out, err = self.run_bzr('diff -r 123', retcode=3,
+            error_regexes=("Requested revision: '123' does not "
+                "exist in branch:",))
+
+    def test_diff_nonexistent_dotted_revision(self):
+        out, err = self.run_bzr('diff -r 1.1', retcode=3)
+        self.assertContainsRe(err,
+            "Requested revision: '1.1' does not exist in branch:")
+
+    def test_diff_nonexistent_dotted_revision_change(self):
+        out, err = self.run_bzr('diff -c 1.1', retcode=3)
+        self.assertContainsRe(err,
+            "Requested revision: '1.1' does not exist in branch:")
 
     def test_diff_unversioned(self):
         # Get an error when diffing a non-versioned file.

=== modified file 'bzrlib/tests/branch_implementations/__init__.py'
--- bzrlib/tests/branch_implementations/__init__.py	2008-07-07 10:31:06 +0000
+++ bzrlib/tests/branch_implementations/__init__.py	2008-11-18 18:43:04 +0000
@@ -184,10 +184,11 @@
     tests.adapt_modules(test_branch_implementations, adapter, loader, result)
 
     # Add RemoteBranch tests, which need a special server.
+    remote_branch_format = RemoteBranchFormat()
     adapt_to_smart_server = BranchTestProviderAdapter(
         SmartTCPServer_for_testing,
         ReadonlySmartTCPServer_for_testing,
-        [(RemoteBranchFormat(), RemoteBzrDirFormat())],
+        [(remote_branch_format, remote_branch_format._matchingbzrdir)],
         MemoryServer,
         name_suffix='-default')
     tests.adapt_modules(test_branch_implementations,
@@ -200,7 +201,7 @@
     adapt_to_smart_server = BranchTestProviderAdapter(
         SmartTCPServer_for_testing_v2_only,
         ReadonlySmartTCPServer_for_testing_v2_only,
-        [(RemoteBranchFormat(), RemoteBzrDirFormat())],
+        [(remote_branch_format, remote_branch_format._matchingbzrdir)],
         MemoryServer,
         name_suffix='-v2')
     tests.adapt_modules(test_branch_implementations,

=== modified file 'bzrlib/tests/branch_implementations/test_branch.py'
--- bzrlib/tests/branch_implementations/test_branch.py	2008-06-25 10:06:48 +0000
+++ bzrlib/tests/branch_implementations/test_branch.py	2008-11-18 18:43:04 +0000
@@ -51,6 +51,14 @@
 from bzrlib.workingtree import WorkingTree
 
 
+class TestTestCaseWithBranch(TestCaseWithBranch):
+
+    def test_branch_format_matches_bzrdir_branch_format(self):
+        bzrdir_branch_format = self.bzrdir_format.get_branch_format()
+        self.assertIs(self.branch_format.__class__,
+                      bzrdir_branch_format.__class__)
+
+
 class TestBranch(TestCaseWithBranch):
 
     def test_create_tree_with_merge(self):

=== modified file 'bzrlib/tests/branch_implementations/test_sprout.py'
--- bzrlib/tests/branch_implementations/test_sprout.py	2008-10-27 01:02:06 +0000
+++ bzrlib/tests/branch_implementations/test_sprout.py	2008-12-01 23:50:52 +0000
@@ -18,6 +18,7 @@
 
 import os
 from bzrlib import (
+    branch as _mod_branch,
     remote,
     revision as _mod_revision,
     tests,
@@ -37,17 +38,17 @@
         target = source.bzrdir.sprout(self.get_url('target')).open_branch()
         self.assertEqual(source.bzrdir.root_transport.base, target.get_parent())
 
-    def test_sprout_preserves_kind(self):
-        branch1 = self.make_branch('branch1')
-        target_repo = self.make_repository('branch2')
-        target_repo.fetch(branch1.repository)
-        branch2 = branch1.sprout(target_repo.bzrdir)
-        if isinstance(branch1, remote.RemoteBranch):
-            branch1._ensure_real()
-            target_class = branch1._real_branch.__class__
-        else:
-            target_class = branch1.__class__
-        self.assertIsInstance(branch2, target_class)
+    def test_sprout_uses_bzrdir_branch_format(self):
+        if isinstance(self.branch_format, _mod_branch.BranchReferenceFormat):
+            raise tests.TestNotApplicable('cannot sprout to a reference')
+        # Start with a format that is unlikely to be the target format
+        source = tests.TestCaseWithTransport.make_branch(self, 'old-branch',
+                                                         format='metaweave')
+        target_bzrdir = self.make_bzrdir('target')
+        target_bzrdir.create_repository()
+        target = source.sprout(target_bzrdir)
+
+        self.assertIs(self.branch_format.__class__, target._format.__class__)
 
     def test_sprout_partial(self):
         # test sprouting with a prefix of the revision-history.

=== modified file 'bzrlib/tests/branch_implementations/test_stacking.py'
--- bzrlib/tests/branch_implementations/test_stacking.py	2008-11-21 20:24:15 +0000
+++ bzrlib/tests/branch_implementations/test_stacking.py	2008-12-01 23:50:52 +0000
@@ -415,7 +415,10 @@
             raise TestNotApplicable()
         # Avoid make_branch, which produces standalone branches.
         bzrdir = self.make_bzrdir('repo/stack-on')
-        b = bzrdir.create_branch()
+        try:
+            b = bzrdir.create_branch()
+        except errors.UninitializableFormat:
+            raise TestNotApplicable()
         transport = self.get_transport('stacked')
         b.bzrdir.clone_on_transport(transport, stacked_on=b.base)
         # Ensure that opening the branch doesn't raise.

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2008-11-28 01:42:05 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2008-12-01 19:07:21 +0000
@@ -291,6 +291,12 @@
         self.assertEqual(self.repository_format,
                          repository.RepositoryFormat.find_format(opened_control))
 
+    def test_format_matchingbzrdir(self):
+        self.assertEqual(self.repository_format,
+            self.repository_format._matchingbzrdir.repository_format)
+        self.assertEqual(self.repository_format,
+            self.bzrdir_format.repository_format)
+
     def test_create_repository(self):
         # bzrdir can construct a repository for itself.
         if not self.bzrdir_format.is_supported():

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2008-09-10 19:14:43 +0000
+++ bzrlib/tests/test_transport.py	2008-12-02 01:22:00 +0000
@@ -225,6 +225,16 @@
                    [(10, 10), (20, 10), (30, 50), (80, 100)],
                   )
 
+    def test_coalesce_default_limit(self):
+        # By default we use a 100MB max size.
+        ten_mb = 10*1024*1024
+        self.check([(0, 10*ten_mb, [(i*ten_mb, ten_mb) for i in range(10)]),
+                    (10*ten_mb, ten_mb, [(0, ten_mb)])],
+                   [(i*ten_mb, ten_mb) for i in range(11)])
+        self.check([(0, 11*ten_mb, [(i*ten_mb, ten_mb) for i in range(11)]),],
+                   [(i*ten_mb, ten_mb) for i in range(11)],
+                   max_size=1*1024*1024*1024)
+
 
 class TestMemoryTransport(TestCase):
 

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2008-11-07 18:10:32 +0000
+++ bzrlib/transport/__init__.py	2008-12-01 23:20:22 +0000
@@ -797,6 +797,10 @@
         cur = _CoalescedOffset(None, None, [])
         coalesced_offsets = []
 
+        if max_size <= 0:
+            # 'unlimited', but we actually take this to mean 100MB buffer limit
+            max_size = 100*1024*1024
+
         for start, size in offsets:
             end = start + size
             if (last_end is not None

=== modified file 'bzrlib/transport/remote.py'
--- bzrlib/transport/remote.py	2008-11-21 00:23:54 +0000
+++ bzrlib/transport/remote.py	2008-12-01 23:20:22 +0000
@@ -323,7 +323,8 @@
         sorted_offsets = sorted(offsets)
         coalesced = list(self._coalesce_offsets(sorted_offsets,
                                limit=self._max_readv_combine,
-                               fudge_factor=self._bytes_to_read_before_seek))
+                               fudge_factor=self._bytes_to_read_before_seek,
+                               max_size=self._max_readv_bytes))
 
         # now that we've coallesced things, avoid making enormous requests
         requests = []

=== modified file 'doc/developers/ppa.txt'
--- doc/developers/ppa.txt	2008-10-28 01:13:06 +0000
+++ doc/developers/ppa.txt	2008-12-01 06:16:21 +0000
@@ -219,6 +219,34 @@
    <https://launchpad.net/~bzr-beta-ppa/+archive/+builds>.
 
 
+Packaging bzr-svn
+~~~~~~~~~~~~~~~~~
+
+bzr-svn uses bzr-builddeb in "split" mode, where the packaging branch
+contains both the source and the ``debian/`` directory, and the
+``orig.tar.gz`` is split off when building the packgae.
+
+To build bzr-svn:
+
+#. Get a checkout of ``lp:~bzr/bzr-svn/hardy-ppa/``
+
+#. Merge from ``http://bzr.debian.org/pkg-bazaar/bzr-svn/experimental/``
+  
+   This should bring in both upstream and packaging changes for the new
+   release, and it's updated as part of the bzr-svn release process.
+
+#. ``export UPSTREAM_VERSION=bzr-svn-0.4.15`` or similar
+
+#. Run ``dch -v 0.4.15-1~bazaar1-hardy1 -D hardy`` or similar
+
+#. Run ``bzr builddeb --source``
+
+   bzr-builddeb will automatically check out the appropriate tag from the
+   main branch of bzr-svn, build, and package it.
+
+#. ``dput bzr-beta-ppa ../bzr-svn_0.4.15-1~bazaar1~hardy1_source.changes``
+
+
 Monitoring the contents of PPAs
 -------------------------------
 

